==> 2.4.zip: piwigo/language/ca_ES/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Actualització";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Aquesta pàgina actualitza la base de dades de la teva antiga galeria Piwigo a la nova versió. L'assistent d'actualització detecta que esteu executant la <strong>versió %s</strong> (o equivalent).";
$lang['Upgrade from version %s to %s'] = "Actualitzar la versió %s a la %s";
$lang['Statistics'] = "Estadístiques";
$lang['total upgrade time'] = "temps total d'actualització";
$lang['total SQL time'] = "temps total SQL ";
$lang['SQL queries'] = "consultes SQL";
$lang['Upgrade informations'] = "Informació de l'actualització";

$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Si trobeu algun problema realitzeu una revisió de manteniment [Administració>Eines>Manteniment].";

$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Com a precaució, els següents connectors s'han desactivat. Haureu de revisar les actualitzacions dels connectors abans de reactivar-los:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Únicament un usuari administrador pot executar l'actualització: si us plau, inicieu la sessió a sota.";
$lang['You do not have access rights to run upgrade'] = "No teniu drets d'accés per executar l'actualització";
$lang['All sub-albums of private albums become private'] = "Tots els sub-àlbums dels àlbums privats esdeveneixen privats";
$lang['User permissions and group permissions have been erased'] = "S'han eliminat els permisos d'usuaris i de grups";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Només s'ha guardat de l'anterior configuració els prefixos de les miniatures i l'adreça de correu electrònic de l'administrador de la web";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'En <i>%s</i>, abans <b>?></b>, insertar:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Com a precaució, els següents tempes s\'han desactivat. Haureu de revisar les actualitzacions dels temes abans de reactivar-los:';
?>

==> 14.5.0.zip: piwigo/language/ca_ES/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Actualització";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Aquesta pàgina actualitza la base de dades de la teva antiga galeria Piwigo a la nova versió. L'assistent d'actualització detecta que esteu executant la <strong>versió %s</strong> (o equivalent).";
$lang['Upgrade from version %s to %s'] = "Actualitzar la versió %s a la %s";
$lang['Statistics'] = "Estadístiques";
$lang['total upgrade time'] = "temps total d'actualització";
$lang['total SQL time'] = "temps total SQL ";
$lang['SQL queries'] = "consultes SQL";
$lang['Upgrade informations'] = "Informació de l'actualització";

$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Si trobeu algun problema realitzeu una revisió de manteniment [Administració>Eines>Manteniment].";

$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Com a precaució, els següents connectors s'han desactivat. Haureu de revisar les actualitzacions dels connectors abans de reactivar-los:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Únicament un usuari administrador pot executar l'actualització: si us plau, inicieu la sessió a sota.";
$lang['You do not have access rights to run upgrade'] = "No teniu drets d'accés per executar l'actualització";
$lang['All sub-albums of private albums become private'] = "Tots els sub-àlbums dels àlbums privats esdeveneixen privats";
$lang['User permissions and group permissions have been erased'] = "S'han eliminat els permisos d'usuaris i de grups";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Només s'ha guardat de l'anterior configuració els prefixos de les miniatures i l'adreça de correu electrònic de l'administrador de la web";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'En <i>%s</i>, abans <b>?></b>, insertar:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Com a precaució, els següents tempes s\'han desactivat. Haureu de revisar les actualitzacions dels temes abans de reactivar-los:';
$lang['Discover what\'s new in Piwigo %s'] = 'Descobriu les novetats de Piwigo %s';
